@@ -59,8 +59,9 @@ def to_tuple(shape):
 
     Returns
     -------
-    If `shape` is None, returns an empty tuple. If it's an int, (shape,) is
-    returned. If it is array-like, tuple(shape) is returned.
+    shape : tuple
+        If `shape` is None, returns an empty tuple. If it's an int, (shape,) is
+        returned. If it is array-like, tuple(shape) is returned.
     """
     if shape is None:
         return tuple()
@@ -321,9 +322,10 @@ def change_dist_size(
 
     Returns
     -------
-    A new distribution variable that is equivalent to the original distribution with
-    the new size. The new distribution will not reuse the old RandomState/Generator
-    input, so it will be independent from the original distribution.
+    dist : TensorVariable
+        A new distribution variable that is equivalent to the original distribution with
+        the new size. The new distribution will not reuse the old RandomState/Generator
+        input, so it will be independent from the original distribution.
 
     Examples
     --------
