@@ -33,30 +33,18 @@
 #   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 #   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 #   SOFTWARE.
-
+import typing
 import warnings
 
-from typing import (
-    Callable,
-    Container,
-    Dict,
-    Generator,
-    Iterable,
-    List,
-    Optional,
-    Sequence,
-    Set,
-    Tuple,
-    Union,
-)
+from typing import Container, Dict, List, Optional, Sequence, Set, Tuple, Union
 
 import numpy as np
+import pytensor
 
 from pytensor import Variable
 from pytensor import tensor as pt
-from pytensor.graph import Apply, Op
+from pytensor.graph import Apply, Op, node_rewriter
 from pytensor.graph.basic import Constant, clone_get_equiv, graph_inputs, walk
-from pytensor.graph.fg import FunctionGraph
 from pytensor.graph.op import HasInnerGraph
 from pytensor.link.c.type import CType
 from pytensor.raise_op import CheckAndRaise
@@ -64,130 +52,99 @@ from pytensor.tensor.random.op import RandomVariable
 from pytensor.tensor.variable import TensorVariable
 
 from pymc.logprob.abstract import MeasurableVariable, _logprob
+from pymc.pytensorf import replace_vars_in_graphs
 from pymc.util import makeiter
 
-
-def walk_model(
-    graphs: Iterable[TensorVariable],
-    walk_past_rvs: bool = False,
-    stop_at_vars: Optional[Set[TensorVariable]] = None,
-    expand_fn: Callable[[TensorVariable], List[TensorVariable]] = lambda var: [],
-) -> Generator[TensorVariable, None, None]:
-    """Walk model graphs and yield their nodes.
-
-    By default, these walks will not go past ``MeasurableVariable`` nodes.
-
-    Parameters
-    ----------
-    graphs
-        The graphs to walk.
-    walk_past_rvs
-        If ``True``, the walk will not terminate at ``MeasurableVariable``s.
-    stop_at_vars
-        A list of variables at which the walk will terminate.
-    expand_fn
-        A function that returns the next variable(s) to be traversed.
-    """
-    if stop_at_vars is None:
-        stop_at_vars = set()
-
-    def expand(var: TensorVariable, stop_at_vars=stop_at_vars) -> List[TensorVariable]:
-        new_vars = expand_fn(var)
-
-        if (
-            var.owner
-            and (walk_past_rvs or not isinstance(var.owner.op, MeasurableVariable))
-            and (var not in stop_at_vars)
-        ):
-            new_vars.extend(reversed(var.owner.inputs))
-
-        return new_vars
-
-    yield from walk(graphs, expand, False)
+if typing.TYPE_CHECKING:
+    from pymc.logprob.transforms import Transform
 
 
-def replace_rvs_in_graphs(
-    graphs: Iterable[TensorVariable],
-    replacement_fn: Callable[
-        [TensorVariable, Dict[TensorVariable, TensorVariable]],
-        Dict[TensorVariable, TensorVariable],
-    ],
-    initial_replacements: Optional[Dict[TensorVariable, TensorVariable]] = None,
-    **kwargs,
-) -> Tuple[TensorVariable, Dict[TensorVariable, TensorVariable]]:
-    """Replace random variables in graphs.
-
-    This will *not* recompute test values.
-
-    Parameters
-    ----------
-    graphs
-        The graphs in which random variables are to be replaced.
-
-    Returns
-    -------
-    A ``tuple`` containing the transformed graphs and a ``dict`` of the
-    replacements that were made.
-    """
-    replacements = {}
-    if initial_replacements:
-        replacements.update(initial_replacements)
-
-    def expand_replace(var: TensorVariable) -> List[TensorVariable]:
-        new_nodes: List[TensorVariable] = []
-        if var.owner and isinstance(var.owner.op, MeasurableVariable):
-            new_nodes.extend(replacement_fn(var, replacements))
-        return new_nodes
-
-    for var in walk_model(graphs, expand_fn=expand_replace, **kwargs):
-        pass
-
-    if replacements:
-        inputs = [i for i in graph_inputs(graphs) if not isinstance(i, Constant)]
-        equiv = {k: k for k in replacements.keys()}
-        equiv = clone_get_equiv(inputs, graphs, False, False, equiv)
-
-        fg = FunctionGraph(
-            [equiv[i] for i in inputs],
-            [equiv[o] for o in graphs],
-            clone=False,
-        )
-
-        fg.replace_all(replacements.items(), import_missing=True)
-
-        graphs = list(fg.outputs)
-
-    return graphs, replacements
-
-
-def rvs_to_value_vars(
-    graphs: Iterable[TensorVariable],
-    initial_replacements: Optional[Dict[TensorVariable, TensorVariable]] = None,
-    **kwargs,
-) -> Tuple[TensorVariable, Dict[TensorVariable, TensorVariable]]:
-    """Replace random variables in graphs with their value variables.
-
-    This will *not* recompute test values in the resulting graphs.
+def replace_rvs_by_values(
+    graphs: Sequence[TensorVariable],
+    *,
+    rvs_to_values: Dict[TensorVariable, TensorVariable],
+    rvs_to_transforms: Optional[Dict[TensorVariable, "Transform"]] = None,
+) -> List[TensorVariable]:
+    """Clone and replace random variables in graphs with their value variables.
 
     Parameters
     ----------
     graphs
         The graphs in which to perform the replacements.
-    initial_replacements
-        A ``dict`` containing the initial replacements to be made.
-
+    rvs_to_values
+        Mapping between the original graph RVs and respective value variables
+    rvs_to_transforms, optional
+        Mapping between the original graph RVs and respective value transforms
     """
 
-    def replace_fn(var, replacements):
-        rv_value_var = replacements.get(var, None)
-        if rv_value_var is not None:
-            replacements[var] = rv_value_var
-            # In case the value variable is itself a graph, we walk it for
-            # potential replacements
-            return [rv_value_var]
-        return []
+    if rvs_to_transforms:
+        # Conditional transforms like Interval can reference variables in the original RV graph
+        # To avoid mutating the original graphs in place, we have to clone them
+        inputs = [i for i in graph_inputs(graphs) if not isinstance(i, Constant)]
+        equiv = clone_get_equiv(inputs, graphs, False, False)
 
-    return replace_rvs_in_graphs(graphs, replace_fn, initial_replacements, **kwargs)
+        graphs = [equiv[g] for g in graphs]
+        rvs_to_values = {equiv.get(rv, rv): value for rv, value in rvs_to_values.items()}
+        rvs_to_transforms = {
+            equiv.get(rv, rv): transform for rv, transform in rvs_to_transforms.items()
+        }
+
+    replacements = {}
+
+    def populate_replacements(var):
+        # Populate replacements dict with {rv: value} pairs indicating which graph
+        # RVs should be replaced by what value variables.
+        if not var.owner:
+            return []
+
+        next_vars = []
+        value = rvs_to_values.get(var, None)
+        if value is not None:
+            rv = var
+
+            if rvs_to_transforms is not None:
+                transform = rvs_to_transforms.get(rv, None)
+                if transform is not None:
+                    # We want to replace uses of the RV by the back-transformation of its value
+                    value = transform.backward(value, *rv.owner.inputs)
+                    # The value may have a less precise type than the rv. In this case
+                    # filter_variable will add a SpecifyShape to ensure they are consistent
+                    value = rv.type.filter_variable(value, allow_convert=True)
+                    value.name = rv.name
+
+            replacements[rv] = value
+            # Also walk the graph of the value variable to make any additional
+            # replacements if that is not a simple input variable
+            next_vars.append(value)
+
+        next_vars.extend(reversed(var.owner.inputs))
+        return next_vars
+
+    # Iterate over the generator to populate the replacements
+    for _ in walk(graphs, populate_replacements, bfs=False):
+        pass
+
+    return replace_vars_in_graphs(graphs, replacements)
+
+
+def rvs_in_graph(vars: Union[Variable, Sequence[Variable]]) -> Set[Variable]:
+    """Assert that there are no `MeasurableVariable` nodes in a graph."""
+
+    def expand(r):
+        owner = r.owner
+        if owner:
+            inputs = list(reversed(owner.inputs))
+
+            if isinstance(owner.op, HasInnerGraph):
+                inputs += owner.op.inner_outputs
+
+            return inputs
+
+    return {
+        node
+        for node in walk(makeiter(vars), expand, False)
+        if node.owner and isinstance(node.owner.op, (RandomVariable, MeasurableVariable))
+    }
 
 
 def convert_indices(indices, entry):
@@ -214,13 +171,18 @@ def indices_from_subtensor(idx_list, indices):
 def check_potential_measurability(
     inputs: Tuple[TensorVariable], valued_rvs: Container[TensorVariable]
 ) -> bool:
+    valued_rvs = set(valued_rvs)
+
+    def expand_fn(var):
+        # expand_fn does not go beyond valued_rvs or any MeasurableVariable
+        if var.owner and not isinstance(var.owner.op, MeasurableVariable) and var not in valued_rvs:
+            return reversed(var.owner.inputs)
+        else:
+            return []
+
     if any(
         ancestor_var
-        for ancestor_var in walk_model(
-            inputs,
-            walk_past_rvs=False,
-            stop_at_vars=set(valued_rvs),
-        )
+        for ancestor_var in walk(inputs, expand=expand_fn, bfs=False)
         if (
             ancestor_var.owner
             and isinstance(ancestor_var.owner.op, MeasurableVariable)
@@ -251,6 +213,48 @@ class CheckParameterValue(CheckAndRaise):
         return f"Check{{{self.msg}}}"
 
 
+@node_rewriter(tracks=[CheckParameterValue])
+def local_remove_check_parameter(fgraph, node):
+    """Rewrite that removes CheckParameterValue
+
+    This is used when compile_rv_inplace
+    """
+    if isinstance(node.op, CheckParameterValue):
+        return [node.inputs[0]]
+
+
+@node_rewriter(tracks=[CheckParameterValue])
+def local_check_parameter_to_ninf_switch(fgraph, node):
+    if not node.op.can_be_replaced_by_ninf:
+        return None
+
+    logp_expr, *logp_conds = node.inputs
+    if len(logp_conds) > 1:
+        logp_cond = pt.all(logp_conds)
+    else:
+        (logp_cond,) = logp_conds
+    out = pt.switch(logp_cond, logp_expr, -np.inf)
+    out.name = node.op.msg
+
+    if out.dtype != node.outputs[0].dtype:
+        out = pt.cast(out, node.outputs[0].dtype)
+
+    return [out]
+
+
+pytensor.compile.optdb["canonicalize"].register(
+    "local_remove_check_parameter",
+    local_remove_check_parameter,
+    use_db_name_as_tag=False,
+)
+
+pytensor.compile.optdb["canonicalize"].register(
+    "local_check_parameter_to_ninf_switch",
+    local_check_parameter_to_ninf_switch,
+    use_db_name_as_tag=False,
+)
+
+
 class DiracDelta(Op):
     """An `Op` that represents a Dirac-delta distribution."""
 
@@ -291,23 +295,3 @@ def diracdelta_logprob(op, values, *inputs, **kwargs):
     (const_value,) = inputs
     values, const_value = pt.broadcast_arrays(values, const_value)
     return pt.switch(pt.isclose(values, const_value, rtol=op.rtol, atol=op.atol), 0.0, -np.inf)
-
-
-def find_rvs_in_graph(vars: Union[Variable, Sequence[Variable]]) -> Set[Variable]:
-    """Assert that there are no `MeasurableVariable` nodes in a graph."""
-
-    def expand(r):
-        owner = r.owner
-        if owner:
-            inputs = list(reversed(owner.inputs))
-
-            if isinstance(owner.op, HasInnerGraph):
-                inputs += owner.op.inner_outputs
-
-            return inputs
-
-    return {
-        node
-        for node in walk(makeiter(vars), expand, False)
-        if node.owner and isinstance(node.owner.op, (RandomVariable, MeasurableVariable))
-    }
