@@ -705,9 +705,9 @@ def test_set_initval():
         alpha = pm.HalfNormal("alpha", initval=100)
         value = pm.NegativeBinomial("value", mu=mu, alpha=alpha)
 
-    assert np.array_equal(model.initial_values[mu], np.array([[100.0]]))
-    np.testing.assert_array_equal(model.initial_values[alpha], np.array(100))
-    assert model.initial_values[value] is None
+    assert np.array_equal(model.rvs_to_initial_values[mu], np.array([[100.0]]))
+    np.testing.assert_array_equal(model.rvs_to_initial_values[alpha], np.array(100))
+    assert model.rvs_to_initial_values[value] is None
 
     # `Flat` cannot be sampled, so let's make sure that doesn't break initial
     # value computations
@@ -715,7 +715,7 @@ def test_set_initval():
         x = pm.Flat("x")
         y = pm.Normal("y", x, 1)
 
-    assert y in model.initial_values
+    assert y in model.rvs_to_initial_values
 
 
 def test_datalogp_multiple_shapes():
@@ -974,18 +974,6 @@ def test_set_data_constant_shape_error():
         pmodel.set_data("y", np.arange(10))
 
 
-def test_model_deprecation_warning():
-    with pm.Model() as m:
-        x = pm.Normal("x", 0, 1, size=2)
-        y = pm.LogNormal("y", 0, 1, size=2)
-
-    with pytest.warns(FutureWarning):
-        m.disc_vars
-
-    with pytest.warns(FutureWarning):
-        m.cont_vars
-
-
 @pytest.mark.parametrize("jacobian", [True, False])
 def test_model_logp(jacobian):
     with pm.Model() as m:
@@ -1114,11 +1102,20 @@ def test_compile_fn():
 
 def test_model_pytensor_config():
     assert pytensor.config.mode != "JAX"
-    with pm.Model(pytensor_config=dict(mode="JAX")) as model:
+    with pytest.warns(FutureWarning, match="pytensor_config is deprecated"):
+        m = pm.Model(pytensor_config=dict(mode="JAX"))
+    with m:
         assert pytensor.config.mode == "JAX"
     assert pytensor.config.mode != "JAX"
 
 
+def test_deprecated_model_property():
+    m = pm.Model()
+    with pytest.warns(FutureWarning, match="Model.model property is deprecated"):
+        m_property = m.model
+    assert m is m_property
+
+
 def test_model_parent_set_programmatically():
     with pm.Model() as model:
         x = pm.Normal("x")
